summaryrefslogtreecommitdiffstats
path: root/chromium/chrome/browser/printing/print_view_manager.h
diff options
context:
space:
mode:
Diffstat (limited to 'chromium/chrome/browser/printing/print_view_manager.h')
-rw-r--r--chromium/chrome/browser/printing/print_view_manager.h13
1 files changed, 11 insertions, 2 deletions
diff --git a/chromium/chrome/browser/printing/print_view_manager.h b/chromium/chrome/browser/printing/print_view_manager.h
index b878a6c6dc0..8415c9ccf35 100644
--- a/chromium/chrome/browser/printing/print_view_manager.h
+++ b/chromium/chrome/browser/printing/print_view_manager.h
@@ -43,8 +43,12 @@ class PrintViewManager : public PrintViewManagerBase,
// a particular WebNode.
void PrintPreviewForWebNode(content::RenderFrameHost* rfh);
- // Notify PrintViewManager that print preview has finished. Unfreeze the
- // renderer in the case of scripted print preview.
+ // Notify PrintViewManager that print preview is about to finish. Unblock the
+ // renderer in the case of scripted print preview if needed.
+ void PrintPreviewAlmostDone();
+
+ // Notify PrintViewManager that print preview has finished. Unblock the
+ // renderer in the case of scripted print preview if needed.
void PrintPreviewDone();
// content::WebContentsObserver implementation.
@@ -77,6 +81,8 @@ class PrintViewManager : public PrintViewManagerBase,
bool source_is_modifiable);
void OnScriptedPrintPreviewReply(IPC::Message* reply_msg);
+ void MaybeUnblockScriptedPreviewRPH();
+
base::OnceClosure on_print_dialog_shown_callback_;
// Current state of print preview for this view.
@@ -89,6 +95,9 @@ class PrintViewManager : public PrintViewManagerBase,
// Keeps track of the pending callback during scripted print preview.
content::RenderProcessHost* scripted_print_preview_rph_ = nullptr;
+ // True if |scripted_print_preview_rph_| needs to be unblocked.
+ bool scripted_print_preview_rph_set_blocked_ = false;
+
// Indicates whether we're switching from print preview to system dialog. This
// flag is true between PrintForSystemDialogNow() and PrintPreviewDone().
bool is_switching_to_system_dialog_ = false;